/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var XML_ADDRESS = "https://www.tizen.org/blogs/feed",
    XML_METHOD = "GET",
    MSG_ERR_NODATA = "There is no news from tizen.org",
    MSG_ERR_NOTCONNECTED = "Connection Aborted. Check your internet connection.",
    MSG_TITLE = "Tizen News",
    NUM_MAX_NEWS = 5,
    NUM_MAX_LENGTH_SUBJECT = 64,
    arrayNews = [],
    indexDisplay = 0,
    lengthNews = 0;

function keyEventCB(event) {
    if (event.keyName === 'back') {
        try {
            tizen.application.getCurrentApplication().exit();
        } catch (ignore) {
        }
    }
}

function trimText(text, maxLength) {
    var trimmedString;

    if (text.length > maxLength) {
        trimmedString = text.substring(0, maxLength - 3) + "...";
    } else {
        trimmedString = text;
    }

    return trimmedString;
}

function resetNewsIndex() {
    indexDisplay = 0;
}

function clearElmText(objElm) {
    objElm.innerHTML = "";
}

function addElmText(objElm, textClass, textContent) {
    objElm.innerHTML = objElm.innerHTML + "<p class='" + textClass + "'>" + textContent + "</p>";
}

function setNews(index) {
    var objNews = document.getElementById('areaNews');

    clearElmText(objNews);
    addElmText(objNews, 'subject', arrayNews[index].title);
}

function setPagenum(index) {
    var objPagenum = document.getElementById('areaPagenum');

    clearElmText(objPagenum);
    addElmText(objPagenum, 'pagenum', "Page " + (index + 1) + "/" + lengthNews);
}

function setTitle() {
    var objTitle = document.getElementById('areaTitle');

    clearElmText(objTitle);
    addElmText(objTitle, 'headerTitle', MSG_TITLE);
}

function showNews() {
    setNews(indexDisplay);
    setPagenum(indexDisplay);
}

function showPrevNews() {
    if (lengthNews > 0) {
        indexDisplay = (indexDisplay + lengthNews - 1) % lengthNews;
        showNews();
    }
}

function showNextNews() {
    if (lengthNews > 0) {
        indexDisplay = (indexDisplay + 1) % lengthNews;
        showNews();
    }
}

function setDefaultEvents() {
    document.addEventListener('tizenhwkey', keyEventCB);
    document.getElementById('areaNews').addEventListener('click', showNextNews);
}

function getDataFromXML() {
    var xmlhttp,
        xmlDoc,
        dataItem,
        objNews = document.getElementById('areaNews'),
        i;

    arrayNews = [];
    lengthNews = 0;
    clearElmText(objNews);
    addElmText(objNews, 'subject', MSG_ERR_NOTCONNECTED);
    xmlhttp = new XMLHttpRequest();

    xmlhttp.open(XML_METHOD, XML_ADDRESS, false);
    xmlhttp.onreadystatechange = function() {
        if (xmlhttp.readyState === 4) {
            if (xmlhttp.status === 200) {
                clearElmText(objNews);

                xmlDoc = xmlhttp.responseXML;
                dataItem = xmlDoc.getElementsByTagName('item');

                if (dataItem.length > 0) {
                    lengthNews = (dataItem.length > NUM_MAX_NEWS) ? NUM_MAX_NEWS : dataItem.length;
                    for (i = 0; i < lengthNews; i++) {
                        arrayNews.push({
                            title: dataItem[i].getElementsByTagName('title')[0].childNodes[0].nodeValue,
                            link: dataItem[i].getElementsByTagName('link')[0].childNodes[0].nodeValue
                        });
                        arrayNews[i].title = trimText(arrayNews[i].title, NUM_MAX_LENGTH_SUBJECT);
                    }
                    resetNewsIndex();
                    showNews();
                } else {
                    addElmText(objNews, 'subject', MSG_ERR_NODATA);
                }

                xmlhttp = null;
            }
        }
    };

    xmlhttp.send();
}

function init() {
    setTitle();
    setDefaultEvents();

    getDataFromXML();
}

window.onload = function() {
    init();
};